@@ -1,8 +1,8 @@
 # $File: //member/autrijus/Unicode-EastAsianWidth/lib/Unicode/EastAsianWidth.pm $ $Author: autrijus $
-# $Revision: #4 $ $Change: 989 $DateTime: $
+# $Revision: #5 $ $Change: 8322 $DateTime: $
 
 package Unicode::EastAsianWidth;
-$Unicode::EastAsianWidth::VERSION = '1.01';
+$Unicode::EastAsianWidth::VERSION = '1.02';
 
 use 5.006;
 use strict;
@@ -16,7 +16,8 @@ Unicode::EastAsianWidth - East Asian Width properties
 
 =head1 VERSION
 
-This document describes version 1.01 of Unicode::EastAsianWidth.
+This document describes version 1.02 of Unicode::EastAsianWidth,
+released October 3, 2003.
 
 =head1 SYNOPSIS
 
@@ -78,12 +79,12 @@ sub InHalfwidth {
 
 ### BEGIN ###
 our @EXPORT = qw(
+InEastAsianAmbiguous
+InEastAsianWide
 InEastAsianFullwidth
 InEastAsianHalfwidth
-InEastAsianAmbiguous
-InEastAsianNarrow
-InEastAsianWide
 InEastAsianNeutral
+InEastAsianNarrow
 InFullwidth
 InHalfwidth
 );
@@ -143,8 +144,8 @@ sub InEastAsianAmbiguous {
 02D8\t02DB
 02DD\t02DD
 02DF\t02DF
-0300\t034F
-0360\t036F
+0300\t0357
+035D\t036F
 0391\t03A1
 03A3\t03A9
 03B1\t03C1
@@ -214,8 +215,7 @@ sub InEastAsianAmbiguous {
 22BF\t22BF
 2312\t2312
 2460\t24E9
-24EB\t24FE
-2500\t254B
+24EB\t254B
 2550\t2573
 2580\t258F
 2592\t2595
@@ -233,6 +233,7 @@ sub InEastAsianAmbiguous {
 2605\t2606
 2609\t2609
 260E\t260F
+2614\t2615
 261C\t261C
 261E\t261E
 2640\t2640
@@ -309,12 +310,10 @@ sub InEastAsianNeutral {
 01D7\t01D7
 01D9\t01D9
 01DB\t01DB
-01DD\t0220
-0222\t0233
+01DD\t0236
 0250\t0250
 0252\t0260
-0262\t02AD
-02B0\t02C3
+0262\t02C3
 02C5\t02C6
 02C8\t02C8
 02CC\t02CC
@@ -322,7 +321,7 @@ sub InEastAsianNeutral {
 02D1\t02D7
 02DC\t02DC
 02DE\t02DE
-02E0\t02EE
+02E0\t02FF
 0374\t0375
 037A\t037A
 037E\t037E
@@ -332,7 +331,7 @@ sub InEastAsianNeutral {
 03AA\t03B0
 03C2\t03C2
 03CA\t03CE
-03D0\t03F6
+03D0\t03FB
 0400\t0400
 0402\t040F
 0450\t0450
@@ -350,19 +349,17 @@ sub InEastAsianNeutral {
 05BB\t05C4
 05D0\t05EA
 05F0\t05F4
-060C\t060C
+0600\t0603
+060C\t0615
 061B\t061B
 061F\t061F
 0621\t063A
-0640\t0655
-0660\t06ED
-06F0\t06FE
-0700\t070D
-070F\t072C
-0730\t074A
+0640\t0658
+0660\t070D
+070F\t074A
+074D\t074F
 0780\t07B1
-0901\t0903
-0905\t0939
+0901\t0939
 093C\t094D
 0950\t0954
 0958\t0970
@@ -373,15 +370,14 @@ sub InEastAsianNeutral {
 09AA\t09B0
 09B2\t09B2
 09B6\t09B9
-09BC\t09BC
-09BE\t09C4
+09BC\t09C4
 09C7\t09C8
 09CB\t09CD
 09D7\t09D7
 09DC\t09DD
 09DF\t09E3
 09E6\t09FA
-0A02\t0A02
+0A01\t0A03
 0A05\t0A0A
 0A0F\t0A10
 0A13\t0A28
@@ -397,8 +393,7 @@ sub InEastAsianNeutral {
 0A5E\t0A5E
 0A66\t0A74
 0A81\t0A83
-0A85\t0A8B
-0A8D\t0A8D
+0A85\t0A8D
 0A8F\t0A91
 0A93\t0AA8
 0AAA\t0AB0
@@ -408,22 +403,23 @@ sub InEastAsianNeutral {
 0AC7\t0AC9
 0ACB\t0ACD
 0AD0\t0AD0
-0AE0\t0AE0
+0AE0\t0AE3
 0AE6\t0AEF
+0AF1\t0AF1
 0B01\t0B03
 0B05\t0B0C
 0B0F\t0B10
 0B13\t0B28
 0B2A\t0B30
 0B32\t0B33
-0B36\t0B39
+0B35\t0B39
 0B3C\t0B43
 0B47\t0B48
 0B4B\t0B4D
 0B56\t0B57
 0B5C\t0B5D
 0B5F\t0B61
-0B66\t0B70
+0B66\t0B71
 0B82\t0B83
 0B85\t0B8A
 0B8E\t0B90
@@ -439,7 +435,7 @@ sub InEastAsianNeutral {
 0BC6\t0BC8
 0BCA\t0BCD
 0BD7\t0BD7
-0BE7\t0BF2
+0BE7\t0BFA
 0C01\t0C03
 0C05\t0C0C
 0C0E\t0C10
@@ -458,7 +454,7 @@ sub InEastAsianNeutral {
 0C92\t0CA8
 0CAA\t0CB3
 0CB5\t0CB9
-0CBE\t0CC4
+0CBC\t0CC4
 0CC6\t0CC8
 0CCA\t0CCD
 0CD5\t0CD6
@@ -562,12 +558,21 @@ sub InEastAsianNeutral {
 1760\t176C
 176E\t1770
 1772\t1773
-1780\t17DC
+1780\t17DD
 17E0\t17E9
+17F0\t17F9
 1800\t180E
 1810\t1819
 1820\t1877
 1880\t18A9
+1900\t191C
+1920\t192B
+1930\t193B
+1940\t1940
+1944\t196D
+1970\t1974
+19E0\t19FF
+1D00\t1D6B
 1E00\t1E9B
 1EA0\t1EF9
 1F00\t1F15
@@ -597,7 +602,7 @@ sub InEastAsianNeutral {
 2034\t2034
 2036\t203A
 203C\t203D
-203F\t2052
+203F\t2054
 2057\t2057
 205F\t2063
 206A\t2071
@@ -616,7 +621,7 @@ sub InEastAsianNeutral {
 2117\t2120
 2123\t2125
 2127\t212A
-212C\t213A
+212C\t213B
 213D\t214B
 2155\t215A
 215F\t215F
@@ -656,7 +661,7 @@ sub InEastAsianNeutral {
 22A6\t22BE
 22C0\t2311
 2313\t2328
-232B\t23CE
+232B\t23D0
 2400\t2426
 2440\t244A
 24EA\t24EA
@@ -689,7 +694,8 @@ sub InEastAsianNeutral {
 266B\t266B
 266E\t266E
 2670\t267D
-2680\t2689
+2680\t2691
+26A0\t26A1
 2701\t2704
 2706\t2709
 270C\t2727
@@ -705,8 +711,9 @@ sub InEastAsianNeutral {
 27B1\t27BE
 27D0\t27E5
 27F0\t2984
-2987\t2AFF
+2987\t2B0D
 303F\t303F
+4DC0\t4DFF
 FB00\tFB06
 FB13\tFB17
 FB1D\tFB36
@@ -718,20 +725,39 @@ FB46\tFBB1
 FBD3\tFD3F
 FD50\tFD8F
 FD92\tFDC7
-FDF0\tFDFC
+FDF0\tFDFD
 FE20\tFE23
 FE70\tFE74
 FE76\tFEFC
 FEFF\tFEFF
 FFF9\tFFFC
+10000\t1000B
+1000D\t10026
+10028\t1003A
+1003C\t1003D
+1003F\t1004D
+10050\t1005D
+10080\t100FA
+10100\t10102
+10107\t10133
+10137\t1013F
 10300\t1031E
 10320\t10323
 10330\t1034A
-10400\t10425
-10428\t1044D
+10380\t1039D
+1039F\t1039F
+10400\t1049D
+104A0\t104A9
+10800\t10805
+10808\t10808
+1080A\t10835
+10837\t10838
+1083C\t1083C
+1083F\t1083F
 1D000\t1D0F5
 1D100\t1D126
 1D12A\t1D1DD
+1D300\t1D356
 1D400\t1D454
 1D456\t1D49C
 1D49E\t1D49F
@@ -740,8 +766,7 @@ FFF9\tFFFC
 1D4A9\t1D4AC
 1D4AE\t1D4B9
 1D4BB\t1D4BB
-1D4BD\t1D4C0
-1D4C2\t1D4C3
+1D4BD\t1D4C3
 1D4C5\t1D505
 1D507\t1D50A
 1D50D\t1D514
@@ -755,6 +780,7 @@ FFF9\tFFFC
 1D6A8\t1D7C9
 1D7CE\t1D7FF
 E0001\tE0001
+E0020\tE007F
 END
 }
 sub InEastAsianNarrow {
@@ -783,20 +809,16 @@ sub InEastAsianWide {
 3105\t312C
 3131\t318E
 3190\t31B7
-31F0\t321C
+31F0\t321E
 3220\t3243
-3251\t327B
-327F\t32CB
-32D0\t32FE
-3300\t3376
-337B\t33DD
-33E0\t33FE
+3250\t327D
+327F\t32FE
+3300\t33FF
 A000\tA48C
 A490\tA4C6
 F900\tFA2D
 FA30\tFA6A
-FE30\tFE46
-FE49\tFE52
+FE30\tFE52
 FE54\tFE66
 FE68\tFE6B
 2F800\t2FA1D
@@ -817,7 +839,7 @@ Autrijus Tang E<lt>autrijus@autrijus.orgE<gt>
 
 =head1 COPYRIGHT
 
-Copyright 2002 by Autrijus Tang E<lt>autrijus@autrijus.orgE<gt>.
+Copyright 2002, 2003 by Autrijus Tang E<lt>autrijus@autrijus.orgE<gt>.
 
 This program is free software; you can redistribute it and/or 
 modify it under the same terms as Perl itself.
